"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const core_1 = require("@babel/core");
//TODO use json file instead???
function generateDevCorePlugins(objectstyles) {
    const devObjectstylesPlugin = function (babel, config, workingPath) {
        const { types: t } = babel;
        return {
            name: "devObjectstylesPlugin",
            visitor: {
                AssignmentExpression(path, state) {
                    if (path.node.left.type !== "MemberExpression") {
                        return;
                    }
                    if (path.node.left.property.type !== "Identifier") {
                        return;
                    }
                    if (path.node.left.property.name !== "default") {
                        return;
                    }
                    if (path.node.right.type !== "ObjectExpression") {
                        return;
                    }
                    if (path.node.right.properties.length) {
                        return;
                    }
                    path.replaceWith(t.assignmentExpression(path.node.operator, path.node.left, t.valueToNode(objectstyles)));
                },
            },
        };
    };
    const code = `
    "use strict";
    // DO NOT CHANGE THIS FILE
    // This file will be generated/overwritten when NODE_ENV is set to development and development mode is enabled
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = {};
    //# sourceMappingURL=devObjectstyles.js.map
  `;
    const output = core_1.transformSync(code, {
        filename: "devObjectstyles.js",
        plugins: [devObjectstylesPlugin],
    });
    //get path to devCorePlugins
    const devObjectstylesPath = require.resolve("xwind/lib/objectstyles/dev/devObjectstyles");
    //overwrite current devCorePlugins file with transformed code
    if (output === null || output === void 0 ? void 0 : output.code) {
        fs_1.default.writeFileSync(devObjectstylesPath, output.code, "utf8");
    }
}
exports.default = generateDevCorePlugins;
//# sourceMappingURL=devObjectstylesGenerator.js.map