"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const transformUtils_1 = require("../../transformUtils");
const import_fresh_1 = __importDefault(require("import-fresh"));
const devObjectstylesGenerator_1 = __importDefault(require("./devObjectstylesGenerator"));
/**
 * Add development imports to the file this enables hot reloading on config changes
 *
 * Example imports:
 * import tailwindconfig from "ABSULUTEPATH/tailwind.config";
 * import devCorePluginsCreator from "@xwind/macro/lib/devCorePluginsCreator"
 * import xwind from "@xwind/macro/lib/xwind";
 * const tw = xwind(tailwindconfig, devCorePluginsCreator);
 */
function devTransform(twConfigPath, paths, state, t, tailwindObjectStyle) {
    const path = state.file.path;
    //create tailwindconfig importDeclaration:
    //import tailwindconfig from "ABSULUTEPATH/tailwind.config";
    const tailwindConfigUid = path.scope.generateUidIdentifier("tailwindconfig");
    const tailwindConfigImport = t.importDeclaration([t.importDefaultSpecifier(tailwindConfigUid)], t.stringLiteral(twConfigPath));
    const devTwUid = path.scope.generateUidIdentifier("devTw");
    const devTwImport = t.importDeclaration([t.importDefaultSpecifier(devTwUid)], t.stringLiteral("xwind/lib/objectstyles/dev/devMergeObjectstyles"));
    const devTwObjectstylesUid = path.scope.generateUidIdentifier("devTwObjectstyles");
    const devTwObjectstylesImport = t.importDeclaration([t.importDefaultSpecifier(devTwObjectstylesUid)], t.stringLiteral("xwind/lib/objectstyles/dev/devObjectstyles"));
    //add devImports nodes to the file
    const programParentNode = path.scope.getProgramParent().path
        .node;
    programParentNode.body.unshift(tailwindConfigImport, devTwImport, devTwObjectstylesImport);
    const objectstyles = {};
    for (const path of paths) {
        const args = transformUtils_1.getArgs(path);
        const classObjectstyles = tailwindObjectStyle(args);
        const twClasses = [];
        const memberExpressions = [];
        for (const [twClass, objectstyle] of classObjectstyles) {
            objectstyles[twClass] = objectstyle;
            twClasses.push(twClass);
            memberExpressions.push(t.memberExpression(devTwObjectstylesUid, t.stringLiteral(twClass), true));
        }
        const replacementAst = t.callExpression(devTwUid, [
            tailwindConfigUid,
            t.valueToNode(twClasses),
            ...memberExpressions,
        ]);
        path.parentPath.replaceWith(replacementAst);
    }
    const cachedObjectstyles = import_fresh_1.default("./devObjectstyles");
    devObjectstylesGenerator_1.default({ ...cachedObjectstyles.default, ...objectstyles });
}
exports.default = devTransform;
//# sourceMappingURL=devTransform.js.map